// ----------------------------------------------------------------------------
// Copyright (C) 2014
//              David Freese, W1HKJ
//
// This file is part of flmsg
//
// flrig is free software; you can redistribute it and/or modify
// it under the terms of the GNU General Public License as published by
// the Free Software Foundation; either version 3 of the License, or
// (at your option) any later version.
//
// flrig is distributed in the hope that it will be useful,
// but WITHOUT ANY WARRANTY; without even the implied warranty of
// MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
// GNU General Public License for more details.
//
// You should have received a copy of the GNU General Public License
// along with this program.  If not, see <http://www.gnu.org/licenses/>.
// ----------------------------------------------------------------------------

#ifndef _TEMPLATES_H
#define _TEMPLATES_H

extern const char cap105_html_template[];
extern const char cap105_txt_template[];
extern const char cap110_html_template[];
extern const char cap110_text_template[];

extern const char ics203_html_template[];
extern const char ics203_text_template[];
extern const char ics205_html_template[];
extern const char ics205_text_template[];
extern const char ics205a_html_template[];
extern const char ics205a_text_template[];
extern const char ics206_html_template[];
extern const char ics206_text_template[];
extern const char ics213_html_template[];
extern const char ics213_text_template[];
extern const char ics214_html_template[];
extern const char ics214_text_template[];
extern const char ics216_html_template[];
extern const char ics216_text_template[];
extern const char ics309_html_template[];
extern const char ics309_text_template[];

extern const char hics203_html_template[];
extern const char hics203_text_template[];
extern const char hics206_html_template[];
extern const char hics206_text_template[];
extern const char hics213_html_template[];
extern const char hics213_text_template[];
extern const char hics214_html_template[];
extern const char hics214_text_template[];

extern const char rg_html_template[];
extern const char rg_html_fcopy_template[];
extern const char rg_txt_template[];
extern const char rg_css[];

extern const char iaru_html_template[];
extern const char iaru_txt_template[];

extern const char pt_html_template[];
extern const char pt_txt_template[];

extern const char blank_html_template[];
extern const char blank_txt_template[];

extern const char csv_html_template[];
extern const char csv_txt_template[];

extern const char baddata_html_template[];

extern const char mars_daily_html_template[];
extern const char mars_daily_text_template[];
extern const char mars_ineei_html_template[];
extern const char mars_ineei_text_template[];
extern const char mars_net_html_template[];
extern const char mars_net_text_template[];

extern const char mars_army_html_template[];
extern const char mars_army_text_template[];

extern const char mars_navy_html_template[];
extern const char mars_navy_text_template[];

extern const char redx_snw_html_template[];
extern const char redx_snw_text_template[];

extern const char redx_5739_html_template[];
extern const char redx_5739_text_template[];

extern const char redx_5739A_html_template[];
extern const char redx_5739A_text_template[];

extern const char redx_5739B_html_template[];
extern const char redx_5739B_text_template[];

extern const char wxhc_html_template[]; 
extern const char wxhc_text_template[];

extern const char severe_wx_html_template[];
extern const char severe_wx_text_template[];

extern const char storm_html_template[];
extern const char storm_text_template[];

#endif

